@@ -13,7 +13,7 @@ from flask import current_app
 
 __author__ = '@Robpol86'
 __license__ = 'MIT'
-__version__ = '0.2.2'
+__version__ = '1.0.0'
 CELERY_LOCK = '_celery.single_instance.{task_name}'
 
 
@@ -71,8 +71,10 @@ class Celery(CeleryClass):
         app.extensions['celery'] = _CeleryState(self, app)
 
         # Instantiate celery and read config.
-        super(Celery, self).__init__(app.import_name, broker=app.config['REDIS_URL'])
-        self._preconf['CELERY_RESULT_BACKEND'] = app.config['REDIS_URL']  # Set result backend default.
+        super(Celery, self).__init__(app.import_name,
+                                     broker=app.config['CELERY_BROKER_URL'])
+        # Set result backend default.
+        self._preconf['CELERY_RESULT_BACKEND'] = app.config['CELERY_RESULT_BACKEND']
         self.conf.update(app.config)
         task_base = self.Task
 
